%bcond_with doc
%bcond_without qt6

Name:		doxygen
Epoch:		1
Version:	1.13.2
Release:	%mkrel 2
Summary:	A documentation system for C/C++
Group:		Development/Other
License:	GPLv2+
URL:		https://www.doxygen.nl/
Source0:	https://doxygen.nl/files/%{name}-%{version}.src.tar.gz
## upstream patches

## mageia patches

## fedora patches


BuildRequires:	bison
BuildRequires:	cmake
BuildRequires:	flex
BuildRequires:	gcc-c++
BuildRequires:	git-core
BuildRequires:	graphviz
BuildRequires:	clang-devel
BuildRequires:	llvm-devel
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(spdlog)
BuildRequires:	pkgconfig(sqlite3)
%if %with qt6
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Xml)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Widgets)
%endif
%if %with doc
BuildRequires:	tetex-latex
BuildRequires:	texlive-collection-basic
BuildRequires:	texlive-dist
BuildRequires:	ghostscript
BuildRequires:	python3
%endif

Requires:	graphviz

%description
Doxygen is a documentation system for C, C++ and IDL. It can generate
an on-line class browser (in HTML) and/or an off-line reference manual
(in LaTeX) from a set of documented source files. There is also
support for generating man pages and for converting the generated
output into Postscript, hyperlinked PDF or compressed HTML. The
documentation is extracted directly from the sources.

Doxygen can also be configured to extract the code-structure from
undocumented source files. This can be very useful to quickly find
your way in large source distributions.

%if %with qt6
%package	doxywizard
Summary:	A GUI for creating and editing configuration files
Group:		Development/Other
Requires:	%{name} = %{epoch}:%{version}

%description	doxywizard
Doxywizard is a GUI for creating and editing configuration files that
are used by doxygen.
%endif

%prep
%autosetup -p1

find -type d -exec chmod 0755 {} \;

# build with system libpng
rm -rf libpng

# build with system swlite3 and spdlog
rm -rf deps/{sqlite3,spdlog}

%build
%cmake \
%if %with doc
	-Dbuild_doc=ON \
%else
	-Dbuild_doc=OFF \
%endif
%if %with qt6
	-Dbuild_wizard=ON \
	-Dforce_qt=Qt6 \
%else
	-Dbuild_wizard=OFF \
%endif
	-Duse_sys_spdlog=ON \
	-Duse_sys_sqlite3=ON \
	-Duse_libclang=ON
%cmake_build

%if %with doc
%cmake_build -t doxygen_pdf
%endif

%install
%cmake_install

%if %with doc
# doxysearch and doxyindexer are not built
rm -rf %{buildroot}%{_mandir}/man1/doxy{search,indexer}
%endif

%if ! %with qt6
rm -rf %{buildroot}%{_mandir}/man1/doxywizard.1*
%endif

%files
%doc README.md
%if %with doc
%doc %{_docdir}/%{name}/html/
%doc %{_docdir}/%{name}/doxygen_manual.pdf
%endif
%{_bindir}/doxygen
%{_mandir}/man1/doxygen.1*

%if %with qt6
%files doxywizard
%{_bindir}/doxywizard
%{_mandir}/man1/doxywizard.1*
%endif


%changelog
* Wed Apr 30 2025 wally <wally> 1:1.13.2-2.mga10
+ Revision: 2180141
- rebuild for llvm 20.1.3

* Mon Apr 07 2025 daviddavid <daviddavid> 1:1.13.2-1.mga10
+ Revision: 2174195
- new version: 1.13.2

* Fri Jan 31 2025 daviddavid <daviddavid> 1:1.10.0-8.mga10
+ Revision: 2143749
- rebuild for new spdlog 1.15.0

* Wed May 08 2024 wally <wally> 1:1.10.0-7.mga10
+ Revision: 2062876
- rebuild for spdlog 1.14.1

* Sun Feb 11 2024 wally <wally> 1:1.10.0-6.mga10
+ Revision: 2040373
- add patch to generate and install man pages

* Sun Feb 11 2024 wally <wally> 1:1.10.0-5.mga10
+ Revision: 2040368
- disable doc build for now
- always install man pages

* Sun Feb 11 2024 wally <wally> 1:1.10.0-4.mga10
+ Revision: 2040348
- disable parallel build for pdf manual

* Sun Feb 11 2024 wally <wally> 1:1.10.0-3.mga10
+ Revision: 2040277
- fix and enable doc build
- add upstream patch to fix linking with spdlog
- switch doxywizard to use Qt6

* Sat Feb 10 2024 wally <wally> 1:1.10.0-2.mga10
+ Revision: 2040180
- build with system sqlite3 and spdlog

* Mon Dec 25 2023 kekepower <kekepower> 1:1.10.0-1.mga10
+ Revision: 2021489
- Update to version 1.10.0

* Sun Sep 03 2023 kekepower <kekepower> 1:1.9.8-1.mga10
+ Revision: 1983814
- Update to version 1.9.8

* Sun May 21 2023 kekepower <kekepower> 1:1.9.7-1.mga9
+ Revision: 1957521
- Update to version 1.9.7

* Tue Dec 27 2022 kekepower <kekepower> 1:1.9.6-1.mga9
+ Revision: 1927169
- Update to version 1.9.6

* Sun Aug 28 2022 kekepower <kekepower> 1:1.9.5-1.mga9
+ Revision: 1881478
- Update to version 1.9.5

* Fri May 06 2022 kekepower <kekepower> 1:1.9.4-1.mga9
+ Revision: 1856486
- Add upstream patch to fix build failure
- Update to version 1.9.4

* Fri Mar 18 2022 umeabot <umeabot> 1:1.9.3-2.mga9
+ Revision: 1797889
- Mageia 9 Mass Rebuild

* Mon Jan 03 2022 luigiwalser <luigiwalser> 1:1.9.3-1.mga9
+ Revision: 1766664
- 1.9.3

* Thu Aug 19 2021 kekepower <kekepower> 1:1.9.2-1.mga9
+ Revision: 1741925
- Update to version 1.9.2

* Fri Jan 08 2021 daviddavid <daviddavid> 1:1.9.1-1.mga8
+ Revision: 1669793
- new version: 1.9.1

* Wed Dec 30 2020 kekepower <kekepower> 1:1.9.0-1.mga8
+ Revision: 1665586
- Update to version 1.9.0

* Wed Dec 16 2020 umeabot <umeabot> 1:1.8.20-2.mga8
+ Revision: 1658329
- Rebuild for new Qt5

* Tue Aug 25 2020 kekepower <kekepower> 1:1.8.20-1.mga8
+ Revision: 1618935
- Update to version 1.8.20

* Sun Aug 09 2020 kekepower <kekepower> 1:1.8.19-1.mga8
+ Revision: 1612150
- Update to version 1.8.19

* Tue Apr 14 2020 luigiwalser <luigiwalser> 1:1.8.18-1.mga8
+ Revision: 1567374
- 1.8.18

* Tue Feb 18 2020 umeabot <umeabot> 1:1.8.17-2.mga8
+ Revision: 1541968
- Mageia 8 Mass Rebuild

* Fri Jan 03 2020 luigiwalser <luigiwalser> 1:1.8.17-1.mga8
+ Revision: 1475788
- 1.8.17
+ wally <wally>
- build with new cmake macros

* Sun Nov 17 2019 daviddavid <daviddavid> 1:1.8.16-1.mga8
+ Revision: 1461537
- new version: 1.8.16
- switch to python3
- remove merged upstream patches
- backport upstream patch to fix issue #7248

* Sat Mar 30 2019 umeabot <umeabot> 1:1.8.15-4.mga7
+ Revision: 1381568
- Qt5 Rebuild

* Wed Mar 13 2019 daviddavid <daviddavid> 1:1.8.15-3.mga7
+ Revision: 1375280
- backport some upstream patches
  * fix doxygen 1.8.15 segfault
  * Properly handle empty TOC in XML output
  * add a test for XML output with an empty TOC
  * Inconsistent whitespace removal for operators in 1.8.15
  * fix multilib issue
- add requirement on dot

* Sun Jan 27 2019 daviddavid <daviddavid> 1:1.8.15-2.mga7
+ Revision: 1361210
- add upstream patch to fix CMake 3.13 incompatibility
  * https://github.com/doxygen/doxygen/issues/6725

* Mon Dec 31 2018 daviddavid <daviddavid> 1:1.8.15-1.mga7
+ Revision: 1347533
- new version: 1.8.15
- remove merged upstream patch
- update URL and Sourve URL

* Sun Sep 23 2018 umeabot <umeabot> 1:1.8.14-4.mga7
+ Revision: 1297494
- Mageia 7 Mass Rebuild

* Wed Jun 06 2018 daviddavid <daviddavid> 1:1.8.14-3.mga7
+ Revision: 1234904
- add patch to fix build with new Qt5 >= 5.11.0

* Tue Dec 26 2017 wally <wally> 1:1.8.14-2.mga7
+ Revision: 1185419
- drop Qt4 support

* Tue Dec 26 2017 shlomif <shlomif> 1:1.8.14-1.mga7
+ Revision: 1185414
- Add BRs
- New version 1.8.14 (thanks to kekePower)

* Tue Jan 10 2017 wally <wally> 1:1.8.13-2.mga6
+ Revision: 1080829
- add patch from upstream to fix opendbx FTBFS

* Thu Dec 29 2016 luigiwalser <luigiwalser> 1:1.8.13-1.mga6
+ Revision: 1078634
- 1.8.13

* Tue Sep 06 2016 luigiwalser <luigiwalser> 1:1.8.12-1.mga6
+ Revision: 1050214
- 1.8.12

* Wed Dec 30 2015 luigiwalser <luigiwalser> 1:1.8.11-1.mga6
+ Revision: 917014
- 1.8.11
- remove patches

* Sat Dec 26 2015 luigiwalser <luigiwalser> 1:1.8.10-1.mga6
+ Revision: 915365
- 1.8.10
- BR graphviz (from fedora)
- if doc, BR texlive-collection-basic (for epstopdf)
- sync patches with fedora
- build with cmake
- reindent spec file

* Wed Oct 15 2014 umeabot <umeabot> 1:1.8.8-4.mga5
+ Revision: 741733
- Second Mageia 5 Mass Rebuild

* Sat Oct 11 2014 danf <danf> 1:1.8.8-3.mga5
+ Revision: 738052
- Added java-enum-crash.patch to fix crash while parsing sources

* Tue Sep 16 2014 umeabot <umeabot> 1:1.8.8-2.mga5
+ Revision: 678824
- Mageia 5 Mass Rebuild

* Fri Aug 22 2014 luigiwalser <luigiwalser> 1:1.8.8-1.mga5
+ Revision: 666353
- 1.8.8

* Mon Apr 21 2014 luigiwalser <luigiwalser> 1:1.8.7-1.mga5
+ Revision: 617294
- 1.8.7
- rediff patch 2

* Fri Jan 17 2014 luigiwalser <luigiwalser> 1:1.8.6-1.mga5
+ Revision: 566771
- 1.8.6
- rediff patch 2

* Sat Oct 19 2013 umeabot <umeabot> 1:1.8.5-3.mga4
+ Revision: 533844
- Mageia 4 Mass Rebuild

* Sat Sep 07 2013 shlomif <shlomif> 1:1.8.5-2.mga4
+ Revision: 475678
- Fix MGA #11163 . No need for specifying the path to make.

* Sat Aug 24 2013 luigiwalser <luigiwalser> 1:1.8.5-1.mga4
+ Revision: 470931
- 1.8.5
- remove upstream patch

* Sun Jun 30 2013 luigiwalser <luigiwalser> 1:1.8.4-1.mga4
+ Revision: 448602
- 1.8.4
- add patch from upstream via fedora to fix endless loop

* Fri Jan 11 2013 umeabot <umeabot> 1:1.8.3-2.mga3
+ Revision: 349076
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 31 2012 fwang <fwang> 1:1.8.3-1.mga3
+ Revision: 336516
- new version 1.8.3

* Wed Sep 26 2012 fwang <fwang> 1:1.8.2-1.mga3
+ Revision: 297836
- new version 1.8.2

* Fri Jul 13 2012 fwang <fwang> 1:1.8.1.2-1.mga3
+ Revision: 270475
- new version 1.8.1.2

* Mon Jun 11 2012 fwang <fwang> 1:1.8.1.1-1.mga3
+ Revision: 259624
- new version 1.8.1.1

* Thu Jun 07 2012 shlomif <shlomif> 1:1.8.1-1.mga3
+ Revision: 256654
- convert tabs to spaces and correct typos
- New version

* Sun Feb 26 2012 fwang <fwang> 1:1.8.0-1.mga2
+ Revision: 215098
- update file list
- new version 1.8.0

* Mon Dec 19 2011 shlomif <shlomif> 1:1.7.6.1-1.mga2
+ Revision: 184419
- New version with bugfixes to hangs (bug 3644)

* Sun Dec 04 2011 fwang <fwang> 1:1.7.6-1.mga2
+ Revision: 175894
- new version 1.7.6
- new version 1.7.5.1
- new version 1.7.5
+ tv <tv>
- new release

* Fri Jan 14 2011 rtp <rtp> 1:1.7.3-1.mga1
+ Revision: 17898
- imported package doxygen


* Wed Jan 05 2011 Oden Eriksson <oeriksson@mandriva.com> 1:1.7.3-1mdv2011.0
+ Revision: 628799
- 1.7.3

* Thu Dec 02 2010 Oden Eriksson <oeriksson@mandriva.com> 1:1.6.3-2mdv2011.0
+ Revision: 604813
- rebuild

* Sun Feb 21 2010 Funda Wang <fwang@mandriva.org> 1:1.6.3-1mdv2010.1
+ Revision: 509120
- New version 1.6.3

* Wed Dec 30 2009 Frederik Himpe <fhimpe@mandriva.org> 1:1.6.2-1mdv2010.1
+ Revision: 484030
- update to new version 1.6.2

* Sun Nov 15 2009 Funda Wang <fwang@mandriva.org> 1:1.6.1-1mdv2010.1
+ Revision: 466225
- New version 1.6.1

* Fri May 01 2009 Frederik Himpe <fhimpe@mandriva.org> 1:1.5.9-1mdv2010.0
+ Revision: 369728
- update to new version 1.5.9

* Tue Jan 13 2009 Pixel <pixel@mandriva.com> 1:1.5.8-3mdv2009.1
+ Revision: 328890
- really fix format-error patch

* Mon Jan 12 2009 Pixel <pixel@mandriva.com> 1:1.5.8-2mdv2009.1
+ Revision: 328706
- fix format-error patch

* Sat Dec 27 2008 Funda Wang <fwang@mandriva.org> 1:1.5.8-1mdv2009.1
+ Revision: 320020
- build qt4 doxywizard
- fix qt4 dir
- fix str fmt
- do not build doc now
- New version 1.5.8

* Wed Nov 26 2008 Funda Wang <fwang@mandriva.org> 1:1.5.7.1-2mdv2009.1
+ Revision: 306904
- conflicts wit old packages
- only use pkg-config to find qt3
- use ldflags
- fix manpage dir

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - update to new version 1.5.7.1

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

* Sun May 18 2008 David Walluck <walluck@mandriva.org> 1:1.5.6-1mdv2009.0
+ Revision: 208769
- BuildRequires: bison
- use %%bcond_without for doc building

  + Funda Wang <fwang@mandriva.org>
    - update to new version 1.5.6

* Mon Feb 18 2008 Thierry Vignaud <tv@mandriva.org> 1:1.5.5-2mdv2008.1
+ Revision: 170799
- rebuild

* Sun Feb 10 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1:1.5.5-1mdv2008.1
+ Revision: 164911
- update to new version 1.5.5

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request
    - buildrequires X11-devel instead of XFree86-devel

* Sat Oct 27 2007 Funda Wang <fwang@mandriva.org> 1:1.5.4-1mdv2008.1
+ Revision: 102546
- New version 1.5.4

* Fri Jul 27 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1:1.5.3-1mdv2008.0
+ Revision: 56340
- new version

* Fri Apr 20 2007 Olivier Blin <oblin@mandriva.com> 1:1.5.2-1mdv2008.0
+ Revision: 16098
- use system libpng
- remove support for obsolete distros
- 1.5.2


* Tue Feb 13 2007 Gwenole Beauchesne <gbeauchesne@mandriva.com> 1:1.5.1-2mdv2007.1
+ Revision: 120646
- fix build on lib64 platforms

* Mon Oct 30 2006 David Walluck <walluck@mandriva.org> 1:1.5.1-1mdv2007.1
+ Revision: 73689
- 1.5.1

* Thu Oct 19 2006 David Walluck <walluck@mandriva.org> 1:1.5.0-4mdv2007.1
+ Revision: 66439
- bump release
- always use threaded version of qt
- set QTDIR on x86_64
- bump release
- fix build on i586
- 1.5.0

  + Andreas Hasenack <andreas@mandriva.com>
    - renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

  + Helio Chissini de Castro <helio@mandriva.com>
    - Uploading package ./doxygen

* Thu Dec 09 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.3.9.1-1mdk
- 1.3.9.1
- drop P1 (fixed upstream)
- wipe out buildroot before installing

* Sat Sep 18 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 1.3.7-4mdk
- use mdkversion

* Fri Jun 04 2004 Laurent Montel <lmontel@mandrakesoft.com> 1.3.7-3mdk
- Rebuild against libstc++

* Sat May 22 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.3.7-2mdk
- fix buildrequires
- don't ship LICENSE, it's gpl..
- cosmetics

* Sat May 15 2004 Michael Scherer <misc@mandrake.org> 1.3.7-1mdk
- New release 1.3.7
- remove Packager

